@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 try:
     from pymongo import ASCENDING, DESCENDING  # NOQA
@@ -12,7 +12,8 @@ try:
     from motorengine.fields import (  # NOQA
         BaseField, StringField, BooleanField, DateTimeField,
         UUIDField, ListField, EmbeddedDocumentField, ReferenceField, URLField,
-        EmailField, IntField, FloatField, DecimalField, BinaryField
+        EmailField, IntField, FloatField, DecimalField, BinaryField,
+        JsonField
     )
 except ImportError:  # NOQA
     pass  # likely setup.py trying to import version
