@@ -5,16 +5,30 @@ from motorengine.fields.base_field import BaseField
 
 
 class ListField(BaseField):
-    def __init__(self, field=None, *args, **kw):
+    '''
+    Field responsible for storing :py:class:`list`.
+
+    Usage::
+
+        posts = ListField(StringField())
+
+
+    Available arguments (apart from those in `BaseField`):
+
+    * `base_field` - ListField must be another field that describe the items in this list
+
+    '''
+
+    def __init__(self, base_field=None, *args, **kw):
         super(ListField, self).__init__(*args, **kw)
 
-        if not isinstance(field, BaseField):
-            raise ValueError("The list field 'field' argument must be an instance of BaseField, not '%s'." % str(field))
+        if not isinstance(base_field, BaseField):
+            raise ValueError("The list field 'field' argument must be an instance of BaseField, not '%s'." % str(base_field))
 
         if not self.default:
             self.default = []
 
-        self._base_field = field
+        self._base_field = base_field
 
     def validate(self, value):
         for item in value:
